JSON-RPC Python
===============
[![pipeline status][pipeline]][homepage]
[![coverage report][coverage]][homepage]
[![latest release][version]][pypi]
[![pypi downloads][downloads]][pypi]

**JSON-RPC Python** is a lightweight WSGI micro framework for building web applications.

Features
--------
* Pure zero-dependency JSON-RPC 2.0 implementation.
* Simple and user-friendly API interface.
* 100% type annotated codebase.
* 100% test coverage, so it's production-ready.

Requirements
------------
Python 3.10 and above.

Installation
------------
```
$ pip install jsonrpc-py
```

Distribution
------------
This project is licensed under the terms of the [Apache License 2.0](LICENSE).

Links
-----
* Documentation: <https://docs.jsonrpc.ru>
* PyPI Releases: <https://pypi.org/project/jsonrpc-py>
* Source Code: <https://gitlab.com/jsonrpc/jsonrpc-py>

[homepage]: <https://gitlab.com/jsonrpc/jsonrpc-py>
[pipeline]: <https://img.shields.io/gitlab/pipeline-status/jsonrpc/jsonrpc-py?branch=development&logo=gitlab&style=flat-square>
[coverage]: <https://img.shields.io/gitlab/coverage/jsonrpc/jsonrpc-py/development?logo=gitlab&style=flat-square>
[pypi]: <https://pypi.org/project/jsonrpc-py>
[version]: <https://img.shields.io/pypi/v/jsonrpc-py?color=steelblue&logo=python&logoColor=steelblue&style=flat-square>
[downloads]: <https://img.shields.io/pypi/dm/jsonrpc-py?color=steelblue&logo=python&logoColor=steelblue&style=flat-square>
